@@ -106,6 +106,12 @@ GMPCSSEndpoint::GMPCSSEndpoint (GMManager & ep)
 }
 
 
+GMPCSSEndpoint::~GMPCSSEndpoint () 
+{
+  delete signal_filter;
+}
+
+
 void GMPCSSEndpoint::AcceptCurrentIncomingCall ()
 {
   if (!incomingConnectionToken.IsEmpty ()) {
@@ -178,8 +184,8 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
 
   PSoundChannel *sound_channel = NULL;
 
-  PString plugin;
-  PString device;
+  gchar *plugin = NULL;
+  gchar *device = NULL;
 
   unsigned int play_vol = 0;
   unsigned int record_vol = 0;
@@ -195,11 +201,9 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
   gm_statusicon_stop_ringing (statusicon);
   gnomemeeting_threads_leave ();
 
-
   /* Suspend the daemons */
   gnomemeeting_sound_daemons_suspend ();
 
-
   /* Open the channel */
   gnomemeeting_threads_enter ();
   plugin = gm_conf_get_string (AUDIO_DEVICES_KEY "plugin");
@@ -209,7 +213,7 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
     device = gm_conf_get_string (AUDIO_DEVICES_KEY "output_device");
   gnomemeeting_threads_leave ();
 
-  if (device.Find (_("No device found")) == P_MAX_INDEX) {
+  if (PString (device).Find (_("No device found")) == P_MAX_INDEX) {
 
     PWaitAndSignal m(sound_event_mutex);
 
@@ -244,6 +248,9 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
 						is_source?(int)record_vol:-1);
       gnomemeeting_threads_leave ();
 
+      g_free (plugin);
+      g_free (device);
+
       return sound_channel;
     }
 
@@ -256,6 +263,8 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
     gnomemeeting_threads_leave ();
   }  
 
+  g_free (plugin);
+  g_free (device);
 
   return NULL;
 }
@@ -289,10 +298,13 @@ GMPCSSEndpoint::OnReleased (OpalConnection &connection)
 
   NoAnswerTimer.Stop ();
   CallPendingTimer.Stop ();
+
   gnomemeeting_threads_enter ();
   gm_statusicon_stop_ringing (statusicon);
   gnomemeeting_threads_leave ();
 
+  gnomemeeting_sound_daemons_resume ();
+
   PTRACE (3, "GMPCSSEndpoint\t PCSS connection released");
   OpalPCSSEndPoint::OnReleased (connection);
 }
