@@ -84,6 +84,15 @@ show_window_cb (GtkWidget *w,
   if (!gnomemeeting_window_is_visible (GTK_WIDGET (data)))
     gnomemeeting_window_show (GTK_WIDGET (data));
   else
+    gtk_window_present (GTK_WINDOW (data));
+}
+
+
+void
+hide_window_cb (GtkWidget *w,
+		gpointer data)
+{
+  if (gnomemeeting_window_is_visible (GTK_WIDGET (data)))
     gnomemeeting_window_hide (GTK_WIDGET (data));
 }
 
@@ -123,50 +132,25 @@ about_callback (GtkWidget *widget,
   const gchar *authors [] = {
       "Damien Sandras <dsandras@seconix.com>",
       "",
-      N_("Code contributors:"),
-      "Benjamin Leviant <belevian@gmail.com>",
-      "Kenneth Rohde Christiansen <kenneth@gnu.org>",
+      N_("Contributors:"),
+      "Kilian Krause <kk@verfaction.de>", 
       "Julien Puydt <julien.puydt@laposte.net>",
-      "Miguel Rodríguez Pérez <miguelrp@gmail.com>",
-      "Paul <paul@argo.dyndns.org>", 
-      "Roger Hardiman <roger@freebsd.org>",
-      "Sébastien Josset <Sebastien.Josset@space.alcatel.fr>",
-      "Sébastien Estienne <sebastien.estienne@gmail.com>",
-      "Stefan Bruëns <lurch@gmx.li>",
-      "Tuan <tuan@info.ucl.ac.be>",
-      "Xavier Ricco <ricco@mulitel.be>",
-      "Julien Hamaide <hamaide@multitel.be>",
+      "Luc Saillard <luc@saillard.org>",
+      "Jan Schampera <jan.schampera@web.de>",
+      "Craig Southeren <craigs@postincrement.com>",
       "",
       N_("Artwork:"),
-      "Jakub Steiner <jimmac@ximian.com>",
       "Carlos Pardo <me@m4de.com>",
+      "Jakub Steiner <jimmac@ximian.com>",
+      "Cédric Valcke <cvalcke@free.fr>",
       "",
-      N_("Contributors:"),
-      "Alexander Larsson <alexl@redhat.com>",
-      "Artur Flinta  <aflinta@at.kernel.pl>",
-      "Bob Mroczka <bob@mroczka.com>",
-      "Chih-Wei Huang <cwhuang@citron.com.tw>",
-      "Christian Rose <menthos@menthos.com>",
-      "Christian Strauf <strauf@uni-muenster.de>",
-      "Christopher R. Gabriel <cgabriel@cgabriel.org>",
-      "Cristiano De Michele <demichel@na.infn.it>",
-      "Fabrice Alphonso <fabrice@alphonso.dyndns.org>",
-      "Florin Grad <florin@mandrakesoft.com>",
-      "Georgi Georgiev <chutz@gg3.net>",
-      "Johnny Ström <jonny.strom@netikka.fi>",
-      "Kilian Krause <kk@verfaction.de>",
-      "Matthias Marks <matthias@marksweb.de>",
-      "Rafael Pinilla <r_pinilla@yahoo.com>",
-      "Santiago García Mantiñán <manty@manty.net>",
-      "Shawn Pai-Hsiang Hsiao <shawn@eecs.harvard.edu>",
-      "Stéphane Wirtel <stephane.wirtel@belgacom.net>",
-      "Vincent Deroo <vincent.deroo@neuf.fr>",
+      N_("See AUTHORS file for full credits"),
       NULL
   };
 	
   authors [2] = gettext (authors [2]);
-  authors [16] = gettext (authors [16]);
-  authors [20] = gettext (authors [20]);
+  authors [9] = gettext (authors [9]);
+  authors [14] = gettext (authors [14]);
   
   const char *documenters [] = {
     "Damien Sandras <dsandras@seconix.com>",
@@ -331,6 +315,8 @@ entry_completion_url_match_cb (GtkEntryCompletion *completion,
 	  gtk_tree_path_free (path);
 	  gtk_tree_path_free (current_path);
 	}
+
+	g_free (tmp_entry);
 	
       } while (gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), 
 					 &tree_iter) && found);
