@@ -95,6 +95,15 @@ typedef struct GmTextChatWindowPage_ GmTextChatWindowPage;
 #define GM_TEXT_CHAT_WINDOW(x) (GmTextChatWindow *) (x)
 #define GM_TEXT_CHAT_WINDOW_PAGE(x) (GmTextChatWindowPage *) (x)
 
+/* the list of magic values for the various styles */
+enum {
+  STYLE_FIRST,
+  STYLE_BOLD,
+  STYLE_ITALIC,
+  STYLE_UNDERLINE,
+  STYLE_LAST,
+};
+
 
 /* Declarations */
 
@@ -237,12 +246,11 @@ static void close_button_clicked_cb (GtkWidget *,
 /* DESCRIPTION  :  Called when a style button of a tab is clicked.
  * BEHAVIOR     :  Update the other buttons and insert the necessary markup
  *                 in the message tab.
- * PRE          :  The pointer must be a valid GINT_TO_POINTER (0, 1, or 2)
- *                 for bold, italic, underline.
+ * PRE          :  The pointer must be a valid GINT_TO_POINTER, corresponding
+ *                 to a valid text style (STYLE_*)
  */
-static void 
-style_button_toggled_cb (GtkToggleButton *widget, 
-			 gpointer data);
+static void style_button_toggled_cb (GtkToggleButton *widget, 
+				     gpointer data);
 
 
 /* DESCRIPTION  :  Called when the send button of a tab is clicked.
@@ -251,9 +259,8 @@ style_button_toggled_cb (GtkToggleButton *widget,
  * PRE          :  The pointer must be a valid pointer to the chat window 
  * 		   GMObject.
  */
-static void 
-send_button_clicked_cb (GtkWidget *widget, 
-		       gpointer data);
+static void send_button_clicked_cb (GtkWidget *widget, 
+				    gpointer data);
 
 
 /* DESCRIPTION  :  Called when the new button of a tab is clicked.
@@ -263,9 +270,8 @@ send_button_clicked_cb (GtkWidget *widget,
  * PRE          :  The pointer must be a valid pointer to the chat window 
  * 		   GMObject.
  */
-static void 
-new_button_clicked_cb (GtkWidget *widget, 
-		       gpointer data);
+static void new_button_clicked_cb (GtkWidget *widget, 
+				   gpointer data);
 
 
 /* DESCRIPTION  :  Called when the URL entry is modified in a page.
@@ -609,7 +615,7 @@ gm_tw_build_tab (GtkWidget *chat_window,
   twp->connect_button = gm_connect_button_new (GM_STOCK_STATUS_IN_A_CALL,
 					       GM_STOCK_STATUS_AVAILABLE,
 					       GTK_ICON_SIZE_MENU,
-					       _("Cl_ear call"),
+					       _("Hang _up"),
 					       _("_Call user"));
   gtk_tooltips_set_tip (tw->tips, twp->connect_button, _("Call this user"), 0); 
   gtk_box_pack_start (GTK_BOX (vbox), twp->connect_button, TRUE, FALSE, 0);
@@ -695,14 +701,14 @@ gm_tw_build_tab (GtkWidget *chat_window,
   /* Signals */
   g_signal_connect (G_OBJECT (twp->bold_button), "toggled",
                     G_CALLBACK (style_button_toggled_cb), 
-		    GINT_TO_POINTER (0));
+		    GINT_TO_POINTER (STYLE_BOLD));
   g_signal_connect (G_OBJECT (twp->italic_button), "toggled",
                     G_CALLBACK (style_button_toggled_cb), 
-		    GINT_TO_POINTER (1));
+		    GINT_TO_POINTER (STYLE_ITALIC));
   g_signal_connect (G_OBJECT (twp->underline_button), "toggled",
                     G_CALLBACK (style_button_toggled_cb), 
-		    GINT_TO_POINTER (2));
-  g_signal_connect (G_OBJECT (twp->connect_button), "clicked",
+		    GINT_TO_POINTER (STYLE_UNDERLINE));
+  g_signal_connect (G_OBJECT (twp->connect_button), "released",
                     G_CALLBACK (connect_button_clicked_cb), 
 		    GTK_ENTRY (twp->remote_url));
   g_signal_connect (GTK_OBJECT (twp->send_button), "clicked",
@@ -882,17 +888,21 @@ style_button_toggled_cb (GtkToggleButton *button,
   
   GtkTextBuffer *buffer = NULL;
   GtkTextIter iter;
+  gint style = 0;
   
   GmTextChatWindowPage *twp = NULL;
   
   chat_window = GnomeMeeting::Process ()->GetChatWindow ();
   twp = gm_tw_get_current_twp (chat_window);
-  
+  style = GPOINTER_TO_INT (data);
+
+  g_return_if_fail (STYLE_FIRST < style && style < STYLE_LAST);
+
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (twp->message));
   gtk_text_buffer_get_end_iter (buffer, &iter);
   
-  switch (GPOINTER_TO_INT (data)) {
-  case 0:
+  switch (style) {
+  case STYLE_BOLD:
     if (gtk_toggle_button_get_active (button)) {
       
       if (GTK_TOGGLE_BUTTON (twp->italic_button)->active)
@@ -910,7 +920,7 @@ style_button_toggled_cb (GtkToggleButton *button,
       gtk_text_buffer_insert (buffer, &iter, "</b>", -1);
       
     break;
-  case 1:
+  case STYLE_ITALIC:
     if (gtk_toggle_button_get_active (button)) {
       
       if (GTK_TOGGLE_BUTTON (twp->bold_button)->active)
@@ -928,7 +938,7 @@ style_button_toggled_cb (GtkToggleButton *button,
       gtk_text_buffer_insert (buffer, &iter, "</i>", -1);
     
     break;
-  case 2:
+  case STYLE_UNDERLINE:
     if (gtk_toggle_button_get_active (button)) {
       
       if (GTK_TOGGLE_BUTTON (twp->italic_button)->active)
@@ -1128,7 +1138,7 @@ gm_tw_urls_history_update_cb (gpointer data)
 					      NULL,
 					      NULL);
   /* Get the full calls history */
-  c2 = gm_calls_history_get_calls (MAX_VALUE_CALL, 25, TRUE);
+  c2 = gm_calls_history_get_calls (MAX_VALUE_CALL, 25, TRUE, FALSE);
   contacts = g_slist_concat (c1, c2);
 
   /* Update all of them */
