@@ -81,9 +81,29 @@ typedef struct _GmDruidWindow GmDruidWindow;
 
 #define GM_DRUID_WINDOW(x) (GmDruidWindow *) (x)
 
+/* make the page numbering less magic */
+enum {
+  PAGE_ZERO, /* doesn't exist */
+  PAGE_FIRST,
+  PAGE_PERSONAL_DATA,
+  PAGE_EKIGA_DOT_NET,
+  PAGE_CONNECTION_TYPE,
+  PAGE_NAT_TYPE,
+  PAGE_AUDIO_MANAGER,
+  PAGE_AUDIO_DEVICES,
+  PAGE_VIDEO_MANAGER,
+  PAGE_VIDEO_DEVICES,
+  PAGE_LAST
+};
 
 /* Declarations */
 
+/* DESCRIPTION  : /
+ * BEHAVIOR     : Filters out "StaticPicture" from the list of available video
+ *                input devices, since it requires further configuration.
+ * PRE          : /
+ */
+static char **get_filtered_video_devices_char_array (PStringArray devices);
 
 /* GUI functions */
 
@@ -373,6 +393,11 @@ static void prepare_gnomemeeting_net_page_cb (GnomeDruidPage *,
 					      gpointer);
 
 
+/* DESCRIPTION  :  Called when the user switches from one page to another.
+ * BEHAVIOR     :  Launched the NAT detection test, except if STUN or IP 
+ * 		   translation are already configured.
+ * PRE          :  The druid window GMObject.
+ */
 static void prepare_nat_page_cb (GnomeDruidPage *page, 
 				 GnomeDruid *druid, 
 				 gpointer data);
@@ -429,6 +454,29 @@ static void gnomemeeting_net_consult_cb (GtkWidget *,
 					 gpointer);
 
 
+static char **
+get_filtered_video_devices_char_array (PStringArray devices)
+{
+  PStringArray preresult;
+  char **unfiltered = NULL;
+  char **result = NULL;
+  int counter = 0;
+
+  unfiltered = devices.ToCharArray ();
+
+  for (counter = 0; unfiltered[counter]; counter++) {
+
+    if (strcmp ("StaticPicture", unfiltered[counter]))
+      preresult += PString (unfiltered[counter]);
+  }
+
+  free (unfiltered);
+
+  result = preresult.ToCharArray ();
+
+  return result;
+}
+
 static void 
 gm_dw_destroy (gpointer d)
 {
@@ -590,7 +638,7 @@ gm_dw_init_welcome_page (GtkWidget *druid_window,
 
   static const gchar text[] =
     N_
-    ("This is the Ekiga general configuration druid. "
+    ("This is the Ekiga general configuration assistant. "
      "The following steps will set up Ekiga by asking "
      "a few simple questions.\n\nOnce you have completed "
      "these steps, you can always change them later by "
@@ -602,7 +650,7 @@ gm_dw_init_welcome_page (GtkWidget *druid_window,
   dw = gm_dw_get_dw (druid_window);
 
   
-  title = g_strdup_printf (_("Configuration Druid - page 1/%d"), t);
+  title = g_strdup_printf (_("Configuration Assistant - page 1/%d"), t);
   
   dw->page_edge =
     GNOME_DRUID_PAGE_EDGE (gnome_druid_page_edge_new_aa (GNOME_EDGE_START));
@@ -712,7 +760,7 @@ gm_dw_init_gnomemeeting_net_page (GtkWidget *druid_window,
 
   page = gnome_druid_page_standard_new ();
 
-  title = g_strdup_printf (_("ekiga.net URL - page %d/%d"), p, t);
+  title = g_strdup_printf (_("ekiga.net Account - page %d/%d"), p, t);
   gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD (page),
 				       title);
   g_free (title);
@@ -936,7 +984,7 @@ gm_dw_init_audio_manager_page (GtkWidget *druid_window,
   page_standard = 
     GNOME_DRUID_PAGE_STANDARD (gnome_druid_page_standard_new ());
   
-  title = g_strdup_printf (_("Audio Endpoint - page %d/%d"), p, t);
+  title = g_strdup_printf (_("Audio Manager - page %d/%d"), p, t);
   gnome_druid_page_standard_set_title (page_standard, title);
   g_free (title);
 
@@ -956,7 +1004,11 @@ gm_dw_init_audio_manager_page (GtkWidget *druid_window,
   gtk_box_pack_start (GTK_BOX (vbox), dw->audio_manager, FALSE, FALSE, 0);
 
   label = gtk_label_new (NULL);
-  text = g_strdup_printf ("<i>%s</i>", _("The audio manager is the plugin that will manage your audio devices, ALSA is probably the best choice when available."));
+#ifdef WIN32
+  text = g_strdup_printf ("<i>%s</i>", _("The audio manager is the plugin that will manage your audio devices. WindowsMultimedia is probably the best choice when available."));
+#else
+  text = g_strdup_printf ("<i>%s</i>", _("The audio manager is the plugin that will manage your audio devices. ALSA is probably the best choice when available."));
+#endif
   gtk_label_set_markup (GTK_LABEL (label), text);
   g_free (text);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
@@ -1090,7 +1142,7 @@ gm_dw_init_video_manager_page (GtkWidget *druid_window,
   page_standard = 
     GNOME_DRUID_PAGE_STANDARD (gnome_druid_page_standard_new ());
   
-  title = g_strdup_printf (_("Video Endpoint - page %d/%d"), p, t);
+  title = g_strdup_printf (_("Video Manager - page %d/%d"), p, t);
   gnome_druid_page_standard_set_title (page_standard, title);
   g_free (title);
 
@@ -1696,18 +1748,23 @@ prepare_nat_page_cb (GnomeDruidPage *page,
   GmDruidWindow *dw = NULL;
   
   GMManager *manager = NULL;
+  int nat_method = 0;
   
+  nat_method = gm_conf_get_int (NAT_KEY "method");
 
   /* Get the data */
   g_return_if_fail (page != NULL && druid != NULL && data != NULL);
 
   dw = gm_dw_get_dw (GTK_WIDGET (data));
 
-  manager = GnomeMeeting::Process ()->GetManager ();
+  if (nat_method == 0) {
 
-  gdk_threads_leave ();
-  manager->CreateSTUNClient (TRUE, TRUE, FALSE, GTK_WIDGET (data));
-  gdk_threads_enter ();
+    manager = GnomeMeeting::Process ()->GetManager ();
+
+    gdk_threads_leave ();
+    manager->CreateSTUNClient (TRUE, TRUE, FALSE, GTK_WIDGET (data));
+    gdk_threads_enter ();
+  }
 }
 
 
@@ -1738,7 +1795,8 @@ prepare_audio_devices_page_cb (GnomeDruidPage *page,
 				FALSE);
   
   if (dw->audio_manager)
-    audio_manager = gtk_combo_box_get_active_text (GTK_COMBO_BOX (dw->audio_manager));
+    audio_manager = 
+      gtk_combo_box_get_active_text (GTK_COMBO_BOX (dw->audio_manager));
 	
   player = gm_conf_get_string (AUDIO_DEVICES_KEY "output_device");
   recorder = gm_conf_get_string (AUDIO_DEVICES_KEY "input_device");
@@ -1833,7 +1891,7 @@ prepare_video_devices_page_cb (GnomeDruidPage *page,
   else 
     gtk_widget_set_sensitive (GTK_WIDGET (dw->video_test_button), TRUE);
   
-  array = devices.ToCharArray ();
+  array = get_filtered_video_devices_char_array (devices);
   gm_dw_option_menu_update (dw->video_device, array, video_recorder);
   free (array);
   
@@ -1948,7 +2006,7 @@ gm_druid_window_new ()
   }
 
   gtk_window_set_title (GTK_WINDOW (window), 
-			_("First Time Configuration Druid"));
+			_("First Time Configuration Assistant"));
   gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
 
 
@@ -1962,16 +2020,16 @@ gm_druid_window_new ()
   gtk_container_add (GTK_CONTAINER (window), GTK_WIDGET (dw->druid));
 
   /* Create the different pages */
-  gm_dw_init_welcome_page (window, 10);
-  gm_dw_init_personal_data_page (window, 2, 10);
-  gm_dw_init_gnomemeeting_net_page (window, 3, 10);
-  gm_dw_init_connection_type_page (window, 4, 10);
-  gm_dw_init_nat_type_page (window, 5, 10);
-  gm_dw_init_audio_manager_page (window, 6, 10);
-  gm_dw_init_audio_devices_page (window, 7, 10);
-  gm_dw_init_video_manager_page (window, 8, 10);
-  gm_dw_init_video_devices_page (window, 9, 10);
-  gm_dw_init_final_page (window, 10);
+  gm_dw_init_welcome_page (window, PAGE_LAST);
+  gm_dw_init_personal_data_page (window, PAGE_PERSONAL_DATA, PAGE_LAST);
+  gm_dw_init_gnomemeeting_net_page (window, PAGE_EKIGA_DOT_NET, PAGE_LAST);
+  gm_dw_init_connection_type_page (window, PAGE_CONNECTION_TYPE, PAGE_LAST);
+  gm_dw_init_nat_type_page (window, PAGE_NAT_TYPE, PAGE_LAST);
+  gm_dw_init_audio_manager_page (window, PAGE_AUDIO_MANAGER, PAGE_LAST);
+  gm_dw_init_audio_devices_page (window, PAGE_AUDIO_DEVICES, PAGE_LAST);
+  gm_dw_init_video_manager_page (window, PAGE_VIDEO_MANAGER, PAGE_LAST);
+  gm_dw_init_video_devices_page (window, PAGE_VIDEO_DEVICES, PAGE_LAST);
+  gm_dw_init_final_page (window, PAGE_LAST);
 
   g_signal_connect (G_OBJECT (dw->druid), "cancel",
 		    G_CALLBACK (cancel_cb), 
