@@ -306,24 +306,11 @@ static void nat_method_update_cb (GtkWidget *,
 				  gpointer);
 
 
-/* DESCRIPTION  :  This callback is called when the user changes
- *                 the sound file in the GtkEntry widget.
- * BEHAVIOR     :  It udpates the config key corresponding the currently
- *                 selected sound event and updates it to the new value
- *                 if required.
- * PRE          :  The preferences window GMObject.
- */
-static void sound_event_changed_cb (GtkEntry *,
-				    gpointer);
-
-
 /* DESCRIPTION  :  This callback is called when the user clicks
  *                 on a sound event in the list.
- * BEHAVIOR     :  It udpates the GtkEntry to the config value for the key
- *                 corresponding to the currently selected sound event.
- *                 The sound_event_changed_cb is blocked to prevent it to
- *                 be triggered when the GtkEntry is udpated with the new
- *                 value.
+ * BEHAVIOR     :  It udpates the GtkFileChooser's filename to the config
+ *                 value for the key corresponding to the currently
+ *                 selected sound event.
  * PRE          :  /
  */
 static void sound_event_clicked_cb (GtkTreeSelection *,
@@ -340,19 +327,6 @@ static void sound_event_play_cb (GtkWidget *,
 				 gpointer);
 
 
-#if !GTK_CHECK_VERSION (2, 3, 2)
-/* DESCRIPTION  :  This callback is called when the user clicks
- *                 on a button of the file selector.
- * BEHAVIOR     :  It sets the selected filename in the good entry (given
- *                 as data of the object because of the bad API). Emits the
- *                 focus-out-event to simulate it.
- * PRE          :  data = the file selector.
- */
-static void file_selector_cb (GtkFileSelection *,
-			      gpointer);
-#endif
-
-
 /* DESCRIPTION  :  This callback is called when the user clicks
  *                 on a sound event in the list and change the toggle.
  * BEHAVIOR     :  It udpates the config key associated with the currently
@@ -365,14 +339,37 @@ static void sound_event_toggled_cb (GtkCellRendererToggle *,
 				    gpointer);
 
 
-/* DESCRIPTION  :  This callback is called when the user clicks
- *                 on the browse button (in the video devices or sound events).
- * BEHAVIOR     :  It displays the file selector widget.
+/* DESCRIPTION  :  This callback is called when the user selected a file
+ *                 with the file selector button for the image
+ * BEHAVIOR     :  Update of the config database.
  * PRE          :  /
  */
-static void browse_cb (GtkWidget *,
-		       gpointer);
+static void image_filename_browse_cb (GtkWidget *,
+				      gpointer);
 
+/* DESCRIPTION  :  This callback is called when the user selected a file
+ *                 for a sound event
+ * BEHAVIOR     :  Update of the config database.
+ * PRE          :  /
+ */
+static void audioev_filename_browse_cb (GtkWidget *,
+					gpointer);
+
+/* DESCRIPTION  :  This callback is used for the preview of the selected
+ *                 image in the file-selector's image
+ * BEHAVIOR     :  Update of the file-selector's image.
+ * PRE          :  /
+ */
+static void image_filename_browse_preview_cb (GtkWidget *,
+                                              gpointer);
+
+/* DESCRIPTION  :  This callback is called by the preview-play button of the
+ * 		   selected audio file in the audio file selector.
+ * BEHAVIOR     :  GMSoundEv's the audio file.
+ * PRE          :  /
+ */
+static void audioev_filename_browse_play_cb (GtkWidget *,
+                                             gpointer);
 
 /* Columns for the codecs page */
 enum {
@@ -685,9 +682,7 @@ gm_pw_init_interface_page (GtkWidget *prefs_window,
   /* GnomeMeeting GUI */
   subsection =
     gnome_prefs_subsection_new (prefs_window, container,
-				_("Ekiga GUI"), 2, 2);
-
-  gnome_prefs_toggle_new (subsection, _("_Show splash screen"), USER_INTERFACE_KEY "show_splash_screen", _("If enabled, the splash screen will be displayed when Ekiga starts"), 0);
+				_("Ekiga GUI"), 1, 2);
 
   gnome_prefs_toggle_new (subsection, _("Start _hidden"), USER_INTERFACE_KEY "start_hidden", _("If enabled, Ekiga will start hidden provided that the notification area is present in the GNOME panel"), 1);
 
@@ -695,7 +690,7 @@ gm_pw_init_interface_page (GtkWidget *prefs_window,
   /* Packing widget */
   subsection =
     gnome_prefs_subsection_new (prefs_window, container, 
-				_("Video Display"), 1, 1);
+				_("Video Display"), 1, 2);
 
   gnome_prefs_toggle_new (subsection, _("Place windows displaying video _above other windows"), VIDEO_DISPLAY_KEY "stay_on_top", _("Place windows displaying video above other windows during calls"), 0);
 }
@@ -731,11 +726,11 @@ gm_pw_init_call_options_page (GtkWidget *prefs_window,
   subsection = gnome_prefs_subsection_new (prefs_window, container,
 					   _("Call Forwarding"), 3, 2);
 
-  gnome_prefs_toggle_new (subsection, _("_Always forward calls to the given host"), CALL_FORWARDING_KEY "always_forward", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above"), 0);
+  gnome_prefs_toggle_new (subsection, _("_Always forward calls to the given host"), CALL_FORWARDING_KEY "always_forward", _("If enabled, all incoming calls will be forwarded to the host that is specified in the protocol settings"), 0);
 
-  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _no answer"), CALL_FORWARDING_KEY "forward_on_no_answer", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above if you do not answer the call"), 1);
+  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _no answer"), CALL_FORWARDING_KEY "forward_on_no_answer", _("If enabled, all incoming calls will be forwarded to the host that is specified in the protocol settings if you do not answer the call"), 1);
 
-  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _busy"), CALL_FORWARDING_KEY "forward_on_busy", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above if you already are in a call or if you are in Do Not Disturb mode"), 2);
+  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _busy"), CALL_FORWARDING_KEY "forward_on_busy", _("If enabled, all incoming calls will be forwarded to the host that is specified in the protocol settings if you already are in a call or if you are in Do Not Disturb mode"), 2);
 
   
   subsection = gnome_prefs_subsection_new (prefs_window, container,
@@ -754,13 +749,14 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
 {
   GmPreferencesWindow *pw= NULL;
 
-  GtkWidget *label = NULL;
-  GtkWidget *entry = NULL;
   GtkWidget *button = NULL;
+  GtkWidget *fsbutton = NULL;
   GtkWidget *hbox = NULL;
   GtkWidget *frame = NULL;
   GtkWidget *vbox = NULL;
   GtkWidget *subsection = NULL;
+  GtkWidget *selector_hbox = NULL;
+  GtkWidget *selector_playbutton = NULL;
 
   GtkListStore *list_store = NULL;
   GtkTreeSelection *selection = NULL;
@@ -768,6 +764,8 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
 
   GtkCellRenderer *renderer = NULL;
 
+  GtkFileFilter *filefilter = NULL;
+
   PStringArray devs;
 
   gchar **array = NULL;
@@ -854,34 +852,43 @@ gm_pw_init_sound_events_page (GtkWidget *prefs_window,
   hbox = gtk_hbox_new (0, FALSE);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 2);
 
-  label = gtk_label_new (_("Sound to play:"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
+  fsbutton =
+    gtk_file_chooser_button_new (_("Choose a sound"),
+				 GTK_FILE_CHOOSER_ACTION_OPEN);
+  gtk_box_pack_start (GTK_BOX (hbox), fsbutton, TRUE, TRUE, 2);
 
-  entry = gtk_entry_new ();
-  gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 2);
+  filefilter = gtk_file_filter_new ();
+  gtk_file_filter_set_name (filefilter, _("Wavefiles"));
+  gtk_file_filter_add_mime_type (filefilter, "audio/x-wav");
 
-  button = gtk_button_new_from_stock (GTK_STOCK_OPEN);
-  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (fsbutton), filefilter);
 
-  g_signal_connect (G_OBJECT (button), "clicked",
-		    G_CALLBACK (browse_cb),
-		    (gpointer) entry);
+  selector_hbox = gtk_hbox_new (FALSE, 0);
+  selector_playbutton = gtk_button_new_with_label (_("Play"));
+  gtk_box_pack_end (GTK_BOX (selector_hbox),
+		    selector_playbutton, FALSE, FALSE, 0);
+  gtk_widget_show (selector_playbutton);
+  gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (fsbutton),
+				     selector_hbox);
+
+  g_signal_connect (G_OBJECT (selector_playbutton), "clicked",
+		    G_CALLBACK (audioev_filename_browse_play_cb),
+		    (gpointer) fsbutton);
+    
+  g_signal_connect (G_OBJECT (fsbutton), "selection-changed",
+		    G_CALLBACK (audioev_filename_browse_cb),
+		    (gpointer) prefs_window);
+
+  g_signal_connect (G_OBJECT (selection), "changed",
+      G_CALLBACK (sound_event_clicked_cb),
+      (gpointer) fsbutton);
 
   button = gtk_button_new_with_label (_("Play"));
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
 
-  g_signal_connect (G_OBJECT (selection), "changed",
-		    G_CALLBACK (sound_event_clicked_cb),
-		    (gpointer) entry);
-
   g_signal_connect (G_OBJECT (button), "clicked",
 		    G_CALLBACK (sound_event_play_cb),
-		    (gpointer) entry);
-
-  g_signal_connect (G_OBJECT (entry), "changed",
-		    G_CALLBACK (sound_event_changed_cb),
-		    (gpointer) prefs_window);
-
+		    (gpointer) fsbutton);
 
   /* Place it after the signals so that we can make sure they are run if
      required */
@@ -1098,11 +1105,16 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
 {
   GmPreferencesWindow *pw = NULL;
 
-  GtkWidget *entry = NULL;
+  GtkWidget *label = NULL;
   GtkWidget *subsection = NULL;
 
   GtkWidget *button = NULL;
 
+  gchar *conf_image = NULL;
+  GtkFileFilter *filefilter = NULL;
+  GtkWidget *preview_image = NULL;
+  GtkWidget *preview_image_frame = NULL;
+
   PStringArray devs;
 
   gchar **array = NULL;
@@ -1157,19 +1169,51 @@ gm_pw_init_video_devices_page (GtkWidget *prefs_window,
   
   gnome_prefs_int_option_menu_new (subsection, _("Format:"), video_format, VIDEO_DEVICES_KEY "format", _("Select the format for video cameras (does not apply to most USB cameras)"), 2);
 
-  entry =
-    gnome_prefs_entry_new (subsection, _("Image:"), VIDEO_DEVICES_KEY "image", _("The image to transmit if \"Picture\" is selected as video plugin or if the opening of the device fails. Leave blank to use the default Ekiga logo."), 4, false);
-
   /* The file selector button */
-  button = gtk_button_new_from_stock (GTK_STOCK_OPEN);
-  gtk_table_attach (GTK_TABLE (subsection), button, 2, 3, 4, 5,
-		    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-		    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-		    GNOMEMEETING_PAD_SMALL, GNOMEMEETING_PAD_SMALL);
+  label = gtk_label_new (_("Image:"));
+  
+  button = gtk_file_chooser_button_new (_("Choose a Picture"),
+					GTK_FILE_CHOOSER_ACTION_OPEN);
 
-  g_signal_connect (G_OBJECT (button), "clicked",
-		    G_CALLBACK (browse_cb),
-		    (gpointer) entry);
+  preview_image_frame = gtk_frame_new (_("Preview"));
+  preview_image = gtk_image_new ();
+  gtk_container_add (GTK_CONTAINER (preview_image_frame), preview_image);
+  gtk_widget_set_size_request (preview_image, 256, 256);
+  gtk_widget_show (preview_image);
+  gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (button),
+				       preview_image_frame);
+
+
+  filefilter = gtk_file_filter_new ();
+  gtk_file_filter_set_name (filefilter, _("Images"));
+  gtk_file_filter_add_mime_type (filefilter, "image/*");
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (button), filefilter);
+  
+  g_signal_connect (G_OBJECT (button), "update-preview",
+		    G_CALLBACK (image_filename_browse_preview_cb),
+		    (gpointer) preview_image);
+  
+  conf_image = gm_conf_get_string (VIDEO_DEVICES_KEY "image");
+  if (conf_image)
+    gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (button), conf_image);
+  g_free (conf_image);
+  
+  gtk_table_attach (GTK_TABLE (subsection), button, 1, 2, 4, 5,
+		    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+		    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+		    0, GNOMEMEETING_PAD_SMALL);
+  
+  gtk_table_attach (GTK_TABLE (subsection), label, 0, 1, 4, 5,
+		    (GtkAttachOptions) (GTK_FILL),
+		    (GtkAttachOptions) (GTK_FILL),
+		    0, 0);
+
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+
+  g_signal_connect (G_OBJECT (button), "selection-changed",
+		    G_CALLBACK (image_filename_browse_cb),
+		    (gpointer) VIDEO_DEVICES_KEY "image");
 
   /* That button will refresh the devices list */
   gm_pw_add_update_button (prefs_window, container, GTK_STOCK_REFRESH, _("_Detect devices"), GTK_SIGNAL_FUNC (refresh_devices_list_cb), _("Click here to refresh the devices list."), 1, NULL);
@@ -1407,117 +1451,63 @@ nat_method_update_cb (GtkWidget *widget,
 }
 
 
-#if !GTK_CHECK_VERSION (2, 3, 2)
-static void  
-file_selector_cb (GtkFileSelection *b, 
-		  gpointer data) 
-{
-  gchar *filename = NULL;
-
-  filename =
-    (gchar *) gtk_file_selection_get_filename (GTK_FILE_SELECTION (data));
-
-  gtk_entry_set_text (GTK_ENTRY (g_object_get_data (G_OBJECT (data), "entry")),
-		      filename);
-
-  g_signal_emit_by_name (G_OBJECT (g_object_get_data (G_OBJECT (data), "entry")), "activate");
-}
-#endif
-
-
 static void
-browse_cb (GtkWidget *b, 
+image_filename_browse_cb (GtkWidget *b, 
 	   gpointer data)
 {
-  GtkWidget *selector = NULL;
-#if GTK_CHECK_VERSION (2, 3, 2)
-  selector = gtk_file_chooser_dialog_new (_("Choose a Picture"),
-					  GTK_WINDOW (gtk_widget_get_toplevel (b)),
-					  GTK_FILE_CHOOSER_ACTION_OPEN, 
-					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					  GTK_STOCK_OPEN,
-					  GTK_RESPONSE_ACCEPT,
-					  NULL);
-  gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (selector), TRUE);
+  char *filename = NULL;
 
-  if (gtk_dialog_run (GTK_DIALOG (selector)) == GTK_RESPONSE_ACCEPT) {
+  filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (b));
+  gm_conf_set_string ((gchar *) data, (gchar *) filename);
 
-    char *filename = NULL;
+  g_free (filename);
 
-    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (selector));
-    gtk_entry_set_text (GTK_ENTRY (data), filename);
-    g_free (filename);
-
-    g_signal_emit_by_name (G_OBJECT (data), "activate");
-  }
-
-  gtk_widget_destroy (selector);
-#else
-  selector = gtk_file_selection_new (_("Choose a Picture"));
-
-  gtk_widget_show (selector);
-
-  /* FIX ME: Ugly hack cause the file selector API is not good and I don't
-     want to use global variables */
-  g_object_set_data (G_OBJECT (selector), "entry", (gpointer) data);
-
-  g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (selector)->ok_button),
-		    "clicked",
-		    G_CALLBACK (file_selector_cb),
-		    (gpointer) selector);
-
-  /* Ensure that the dialog box is destroyed when the user clicks a button. */
-  g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (selector)->ok_button),
-			    "clicked",
-			    G_CALLBACK (gtk_widget_destroy),
-			    (gpointer) selector);
-
-  g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (selector)->cancel_button),
-			    "clicked",
-			    G_CALLBACK (gtk_widget_destroy),
-			    (gpointer) selector);
-
-#endif
+  /* On the very first time, when we only set the file name from the GMC
+   * the update-preview signal isn't sent. We do it manually here on the
+   * "selection-changed" */
+  g_signal_emit_by_name (G_OBJECT (b), "update-preview");
 }
 
 
 static void
-sound_event_changed_cb (GtkEntry *entry,
-			gpointer data)
+audioev_filename_browse_cb (GtkWidget *b,
+     gpointer data)
 {
+
   GmPreferencesWindow *pw = NULL;
 
   GtkTreeModel *model = NULL;
   GtkTreeSelection *selection = NULL;
   GtkTreeIter iter;
 
-  const char *entry_text = NULL;
+  const char *filename = NULL;
   gchar *conf_key = NULL;
   gchar *sound_event = NULL;
 
-
   g_return_if_fail (data != NULL);
   pw = gm_pw_get_pw (GTK_WIDGET (data));
 
   selection =
     gtk_tree_view_get_selection (GTK_TREE_VIEW (pw->sound_events_list));
+
   if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 
     gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
-			2, &conf_key, -1);
+      2, &conf_key, -1);
 
-    if (conf_key) { 
-
-      entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
-      sound_event = gm_conf_get_string (conf_key);
-
-      if (!sound_event || strcmp (entry_text, sound_event))
-	gm_conf_set_string (conf_key, (gchar *) entry_text);
+    if (conf_key) {
+      filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (b));
+      if (filename) {
+        sound_event = gm_conf_get_string (conf_key);
+        
+        if (!sound_event || strcmp (filename, sound_event))
+          gm_conf_set_string (conf_key, (gchar *) filename);
+      }
 
       g_free (conf_key);
       g_free (sound_event);
     }
-  } 
+  }
 }
 
 
@@ -1539,18 +1529,9 @@ sound_event_clicked_cb (GtkTreeSelection *selection,
     if (conf_key) { 
 
       sound_event = gm_conf_get_string (conf_key);
-      g_signal_handlers_block_matched (G_OBJECT (data),
-				       G_SIGNAL_MATCH_FUNC,
-				       0, 0, NULL,
-				       (gpointer) sound_event_changed_cb,
-				       NULL);
+
       if (sound_event)
-	gtk_entry_set_text (GTK_ENTRY (data), sound_event);
-      g_signal_handlers_unblock_matched (G_OBJECT (data),
-					 G_SIGNAL_MATCH_FUNC,
-					 0, 0, NULL,
-					 (gpointer) sound_event_changed_cb,
-					 NULL);
+        gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (data), sound_event);
 
       g_free (conf_key);
       g_free (sound_event);
@@ -1567,7 +1548,7 @@ sound_event_play_cb (GtkWidget *b,
   
   g_return_if_fail (data != NULL);
 
-  event = gtk_entry_get_text (GTK_ENTRY (data));
+  event = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data));
 
   if (!event.IsEmpty ())
     GMSoundEvent ev(event);
@@ -1602,6 +1583,60 @@ sound_event_toggled_cb (GtkCellRendererToggle *cell,
   gtk_tree_path_free (path);
 }
 
+static void
+image_filename_browse_preview_cb (GtkWidget *selector,
+				  gpointer data)
+{
+  GtkWidget *previewer = NULL;
+  char *filename = NULL;
+  GdkPixbuf *pixbuf = NULL;
+
+  g_return_if_fail (data != NULL);
+
+  previewer = GTK_WIDGET (data);
+
+  filename =
+    gtk_file_chooser_get_preview_filename (GTK_FILE_CHOOSER (selector));
+  /* no filename? try next method */
+  if (!filename)
+    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (selector));
+
+  /* FIXME: still no luck? take from config */
+  if (!filename)
+    filename = gm_conf_get_string (VIDEO_DEVICES_KEY "image");
+
+  if (filename)
+    pixbuf = gdk_pixbuf_new_from_file_at_size (filename,
+					       256, 256,
+					       NULL);
+
+  g_free (filename);
+
+  gtk_image_set_from_pixbuf (GTK_IMAGE (previewer), pixbuf);
+
+  if (pixbuf) g_object_unref (pixbuf);
+
+  gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (selector),
+					      TRUE);
+}
+
+
+static void
+audioev_filename_browse_play_cb (GtkWidget *playbutton,
+				 gpointer data)
+{
+  char *filename = NULL;
+
+  g_return_if_fail (data != NULL);
+
+  filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data));
+
+  if (filename)
+    GMSoundEvent ev((const char*) filename);
+
+  g_free (filename);
+}
+
 
 /* Public functions */
 void 
